@@ -1,6 +1,6 @@
-# Copyright 2009-2010 by Roger Bivand
+# Copyright 2009-2011 by Roger Bivand
 
-trW <- function(W=NULL, m=30, p=16, type="mult", listw=NULL) {
+trW <- function(W=NULL, m=30, p=16, type="mult", listw=NULL, momentsSymmetry=TRUE) {
 # returns traces
     timings <- list()
     .ptime_start <- proc.time()
@@ -19,18 +19,28 @@ trW <- function(W=NULL, m=30, p=16, type="mult", listw=NULL) {
         stopifnot(inherits(W, "sparseMatrix"))
         n <- dim(W)[1]
         tr <- numeric(m)
+# return sd of traces 111126
+        sdtr <- numeric(m)
         x <- matrix(rnorm(n*p), nrow=n, ncol=p)
         xx <- x
         for (i in 1:m) {
             xx <- W %*% xx
-            tr[i] <- sum(apply(x * as.matrix(xx), 2,  function(y) sum(y)/p))
+# return sd of traces 111126
+            v <- apply(x * as.matrix(xx), 2, sum)
+            tr[i] <- mean(v)
+            sdtr[i] <- sd(v)/sqrt(p)
+#            tr[i] <- sum(apply(x * as.matrix(xx), 2,  function(y) sum(y)/p))
 # mean replaced by sum(y)/p 091012, 0.4-47
         }
         tr[1] <- 0.0
         tr[2] <- sum(t(W) * W)
+# return sd of traces 111126
+        sdtr[1:2] <- NA
+        attr(tr, "sd") <- sdtr
     } else if (type == "moments") {
         if (!is.null(W) && is.null(listw)) {
-            if (!is(W, "symmetricMatrix")) stop("moments require symmetric W")
+            if (momentsSymmetry && !is(W, "symmetricMatrix"))
+                stop("moments require symmetric W")
             listw <- mat2listw(W)
         }
         tr <- mom_calc(listw, m)
@@ -279,7 +289,7 @@ intImpacts <- function(rho, beta, P, n, mu, Sigma, irho, drop2beta, bnames,
             }
             timings[["impacts_samples"]] <- proc.time() - .ptime_start
             .ptime_start <- proc.time()
-            CL <- get("cl", env = .spdepOptions)
+            CL <- get("cl", envir = .spdepOptions)
             if (!is.null(CL) && length(CL) > 1L) {
                 require(snow)
                 l_sp <- lapply(splitIndices(nrow(samples), length(CL)), 
@@ -287,7 +297,7 @@ intImpacts <- function(rho, beta, P, n, mu, Sigma, irho, drop2beta, bnames,
                 clusterEvalQ(CL, library(spdep))
 		clusterExport_l <- function(CL, list) {
                     gets <- function(n, v) {
-                        assign(n, v, env = .GlobalEnv)
+                        assign(n, v, envir = .GlobalEnv)
                         NULL
                     }
                     for (name in list) {
@@ -373,7 +383,7 @@ intImpacts <- function(rho, beta, P, n, mu, Sigma, irho, drop2beta, bnames,
             timings[["impacts_samples"]] <- proc.time() - .ptime_start
             .ptime_start <- proc.time()
 # type, iicept, icept, SW, n, listw
-            CL <- get("cl", env = .spdepOptions)
+            CL <- get("cl", envir = .spdepOptions)
             if (!is.null(CL) && length(CL) > 1L) {
                 require(snow)
                 l_sp <- lapply(splitIndices(nrow(samples), length(CL)), 
@@ -381,7 +391,7 @@ intImpacts <- function(rho, beta, P, n, mu, Sigma, irho, drop2beta, bnames,
                 clusterEvalQ(CL, library(spdep))
 		clusterExport_l <- function(CL, list) {
                     gets <- function(n, v) {
-                        assign(n, v, env = .GlobalEnv)
+                        assign(n, v, envir = .GlobalEnv)
                         NULL
                     }
                     for (name in list) {
