@@ -12,7 +12,7 @@ localmoran.sad <- function (model, select, nb, glist = NULL, style = "W",
     if (!inherits(nb, "nb"))
         stop(paste(deparse(substitute(nb)), "not an nb object"))
         if (is.null(zero.policy))
-            zero.policy <- get("zeroPolicy", env = .spdepOptions)
+            zero.policy <- get("zeroPolicy", envir = .spdepOptions)
         stopifnot(is.logical(zero.policy))
     n <- length(nb)
     dmc <- deparse(model$call)
