@@ -41,7 +41,7 @@ subset.nb <- function(x, subset, ...) {
 subset.listw <- function(x, subset, zero.policy=NULL, ...) {
     if (!inherits(x, "listw")) stop("not a weights list")
         if (is.null(zero.policy))
-            zero.policy <- get("zeroPolicy", env = .spdepOptions)
+            zero.policy <- get("zeroPolicy", envir = .spdepOptions)
         stopifnot(is.logical(zero.policy))
     if (!is.logical(subset)) stop("subset not a logical vector")
     nb <- x$neighbours
